@@ -5,8 +5,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KIMAP_LOGINJOB_H
-#define KIMAP_LOGINJOB_H
+#pragma once
 
 #include "kimap_export.h"
 
@@ -107,4 +106,3 @@ private:
 
 }
 
-#endif
